/* SPDX-License-Identifier: GPL-2.0-only */

#include <device/azalia_device.h>

const u32 cim_verb_data[] = {
	/* Realtek ALC269VC */
	0x10ec0269,
	0x15581314,
	11,
	AZALIA_SUBVENDOR(0, 0x15581314),
	AZALIA_PIN_CFG(0, 0x12, 0x90a60140),
	AZALIA_PIN_CFG(0, 0x14, 0x90170120),
	AZALIA_PIN_CFG(0, 0x15, 0x02211010),
	AZALIA_PIN_CFG(0, 0x17, 0x40000000),
	AZALIA_PIN_CFG(0, 0x18, 0x02a11030),
	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1a, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1d, 0x40f4a205),
	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),

	/* Intel iGPU HDMI */
	0x8086280b,
	0x80860101,
	4,
	AZALIA_SUBVENDOR(2, 0x80860101),
	AZALIA_PIN_CFG(2, 0x5, 0x18560010),
	AZALIA_PIN_CFG(2, 0x6, 0x18560010),
	AZALIA_PIN_CFG(2, 0x7, 0x18560010)
};

const u32 pc_beep_verbs[] = {};

AZALIA_ARRAY_SIZES;
